package ruon.jiao;

public class MetaConfig {

    final public static String Boolean = "Boolean";
    final public static String Integer = "Integer";
    final public static String String = "String";
    final public static String Text = "Text";

    public static class Parameter {
        private String name;
        private String type;
        private String def;
        private boolean secret;
        private String unit;

        public Parameter(String name, String type, String unit, Object def, boolean secret) {
            this.name = name;
            this.type = type;
            this.unit = unit;
            this.def = def.toString();
            this.secret = secret;
        }
        public Parameter(String name, String type, Object def) {
            this(name, type, null, def, false);
        }
        public Parameter(String name, String type, String unit, Object def) {
            this(name, type, unit, def, false);
        }
        private void toXML(StringBuilder sb) {
            sb.append("<param name=\"");
            sb.append(name);
            sb.append("\" type=\"");
            sb.append(type);
            if (unit!=null) {
                sb.append("[").append(unit).append("]");
            }
            //sb.append("\" default=\"");
            //sb.append(def);
            sb.append("\"");
            if (secret) {
                sb.append("secret=\"true\"");
            }
            sb.append(">");
            sb.append("<![CDATA[");
            sb.append(def);
            sb.append("]]>");
            sb.append("</param>");
        }
    }

    private Parameter [] agentParameters;
    private Parameter [] resourceParameters;

    public MetaConfig(Parameter[] agentParameters, Parameter[] resourceParameters) {
        this.agentParameters = agentParameters;
        this.resourceParameters = resourceParameters;
    }
    public MetaConfig(Parameter[] agentParameters) {
        this(agentParameters, new Parameter[]{});
    }


    String toXML() {
        StringBuilder sb = new StringBuilder();
        sb.append("<fetchconfig>");
        sb.append("<agent>");
        toXML(sb, agentParameters);
        sb.append("</agent><resources>");
        toXML(sb, resourceParameters);
        sb.append("</resources></fetchconfig>");
        return sb.toString();
    }

    private void toXML(StringBuilder sb, Parameter[] parameters) {
        //noinspection ForLoopReplaceableByForEach
        for (int i=0;i<parameters.length;++i) {
            parameters[i].toXML(sb);
        }
    }

}
